# Contents
This demo showcases common features for creating web applications:

- Themes
- Config based API model
- WebSockets
- Server-sent Events
- Plugin system

# Plugins
Plugins are custom features that extends your applications functionality. Plugins can apply to parsely files
or apply as a sub-application.

Plugins directory will store the plugin source code and any related data.

**Pyonir ships with the following optional plugins:**

- Forms
- Navigation
- FileUploader
- Ecommerce